@@ -2061,7 +2061,7 @@ src_surroundings_logic ()
     if (!sro_get_sro (src_crt_sro, SR_NAV_PARENT, &parent, SR_NAV_MODE_WINDOW))
 	return FALSE;
     
-    while (!has_parent_stop_role (parent))
+    while (parent && !has_parent_stop_role (parent))
     {
 	SRObject *tmp;
 	if (!sro_get_sro (parent, SR_NAV_PARENT, &tmp, SR_NAV_MODE_WINDOW))
