@@ -446,9 +446,8 @@ src_magnifier_create_mml(const Magnifier *magnifier)
     if (magnifier->mag_id == NULL) 		return NULL;
 
     if (magnifier->mag_source == NULL) 		return NULL;
-/*
     if (magnifier->mag_target == NULL) 		return NULL;
-*/
+
     if (magnifier->mag_smoothing == NULL ) 	return NULL;
     if (magnifier->mag_mouse_tracking == NULL)	return NULL;
 
@@ -463,6 +462,7 @@ src_magnifier_create_mml(const Magnifier *magnifier)
 			    " CrosswireColor=\"%ld\">"
 			    " <ZOOMER ID=\"%s\" "
 			    " source=\"%s\""
+			    " target=\"%s\""
 			    " BorderWidth=\"%d\""
 			    " BorderColor=\"%ld\""
 			    " ZPLeft=\"%d\""
@@ -491,6 +491,7 @@ src_magnifier_create_mml(const Magnifier *magnifier)
 
 			    magnifier->mag_id,
 			    magnifier->mag_source,
+			    magnifier->mag_target,
 			    magnifier->mag_border_width,
 			    magnifier->mag_border_color,
 			    magnifier->mag_zp_left,
